==> exo.jcr.component.ext-1.9.3.1-sources.jar: org/exoplatform/services/jcr/ext/metadata/SetDCMetadataAction.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.jcr.ext.metadata;

import javax.jcr.Value;

import org.apache.commons.chain.Context;
import org.exoplatform.services.command.action.Action;
import org.exoplatform.services.jcr.impl.core.NodeImpl;
import org.exoplatform.services.jcr.impl.core.value.ValueFactoryImpl;

/**
 * for node operations like addNode, checkin 
 * @author <a href="mailto:Sergey.Kabashnyuk@gmail.com">Sergey Kabashnyuk</a>
 * @version $Id: $
 */
public class SetDCMetadataAction implements Action{

  public boolean execute(Context ctx) throws Exception {
    NodeImpl node = (NodeImpl)ctx.get("currentItem");
    if (node.canAddMixin("dc:elementSet"))
      node.addMixin("dc:elementSet");
    node.setProperty("dc:creator", new String[] { node.getSession().getUserID() });
    ValueFactoryImpl vf = node.getSession().getValueFactory();
      
    node.setProperty("dc:date", new Value[] { vf.createValue(       
        node.getSession().getTransientNodesManager()
        .getTransactManager().getStorageDataManager().getCurrentTime())});
    
    return false;
  }

}

==> exo.jcr.component.ext-1.10.12-sources.jar: org/exoplatform/services/jcr/ext/metadata/SetDCMetadataAction.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.jcr.ext.metadata;

import javax.jcr.Value;

import org.apache.commons.chain.Context;
import org.exoplatform.services.command.action.Action;
import org.exoplatform.services.jcr.impl.core.NodeImpl;
import org.exoplatform.services.jcr.impl.core.value.ValueFactoryImpl;

/**
 * for node operations like addNode, checkin
 * 
 * @author <a href="mailto:Sergey.Kabashnyuk@gmail.com">Sergey Kabashnyuk</a>
 * @version $Id: SetDCMetadataAction.java 35186 2009-08-07 14:23:43Z pnedonosko $
 */
public class SetDCMetadataAction implements Action {

  public boolean execute(Context ctx) throws Exception {
    NodeImpl node = (NodeImpl) ctx.get("currentItem");
    if (node.canAddMixin("dc:elementSet"))
      node.addMixin("dc:elementSet");
    node.setProperty("dc:creator", new String[] { node.getSession().getUserID() });
    ValueFactoryImpl vf = node.getSession().getValueFactory();

    node.setProperty("dc:date", new Value[] { vf.createValue(node.getSession()
                                                                 .getTransientNodesManager()
                                                                 .getTransactManager()
                                                                 .getStorageDataManager()
                                                                 .getCurrentTime()) });

    return false;
  }

}
